.. _papers:

Papers
------

The following papers use **PyAutoLens**:

**Dark Matter**

`A forward-modelling method to infer the dark matter particle mass from strong gravitational lenses  <https://arxiv.org/abs/2010.13221>`_

`Dark disk substructure and superfluid dark matter <https://arxiv.org/abs/1901.03694>`_

`Galaxy-galaxy strong lens perturbations: line-of-sight haloes versus lens subhaloes <https://arxiv.org/abs/2110.04512>`_

`Halo concentration strengthens dark matter constraints in galaxy–galaxy strong lensing analyses <https://arxiv.org/abs/2109.00018>`_

`Novel Substructure & Superfluid Dark Matter <https://arxiv.org/abs/1901.03694>`_

**Cosmology**

`Probing General Relativity in galactic scales at z ∼0.3 <https://arxiv.org/abs/2212.08463>`_

`Why weak lensing cluster shapes are insensitive to self-interacting dark matter <https://arxiv.org/abs/2210.13474>`_

**Galaxy Formation & Evolution**

`Two-dimensional kinematics and dynamical modelling of the 'Jackpot' gravitational lens from deep MUSE observations <https://arxiv.org/abs/2401.08771>`_

`Beyond the bulge-halo conspiracy? Density profiles of Early-type galaxies from extended-source strong lensing <https://arxiv.org/abs/2207.04070>`_

`Galaxy structure with strong gravitational lensing: decomposing the internal mass distribution of massive elliptical galaxies <https://arxiv.org/abs/1901.07801>`_

`Microlensing and the type Ia supernova iPTF16geu <https://arxiv.org/abs/2112.04524>`_

**Lens Modeling / Theory**

`Strong gravitational lensings external shear is not shear <https://arxiv.org/abs/2301.05244>`_

`Automated galaxy-galaxy strong lens modelling: no lens left behind <https://arxiv.org/abs/2202.09201>`_

`Systematic Errors Induced by the Elliptical Power-law model in Galaxy–Galaxy Strong Lens Modeling <https://arxiv.org/abs/2110.14554>`_

`Testing strong lensing subhalo detection with a cosmological simulation <https://arxiv.org/abs/2202.10191>`_

**Statistics / Machine Learning**

`A machine learning based approach to gravitational lens identification with the International LOFAR Telescope <https://arxiv.org/abs/2207.10698>`_

`Auto-identification of unphysical source reconstructions in strong gravitational lens modelling <https://arxiv.org/abs/2012.04665>`_

`Decoding Dark Matter Substructure without Supervision <https://arxiv.org/abs/2008.12731>`_

`Deep Learning the Morphology of Dark Matter Substructure <https://arxiv.org/abs/1909.07346>`_

`Domain Adaptation for Simulation-Based Dark Matter Searches Using Strong Gravitational Lensing <https://arxiv.org/abs/2112.12121>`_

`Likelihood-free MCMC with Amortized Approximate Likelihood Ratios <https://arxiv.org/abs/1903.04057>`_

`On machine learning search for gravitational lenses <https://arxiv.org/abs/2104.01014>`_

`Strong lens modelling: comparing and combining Bayesian neural networks and parametric profile fitting <https://arxiv.org/abs/2103.03257>`_

`Streamlined Lensed Quasar Identification in Multiband Images via Ensemble Networks <https://arxiv.org/abs/2307.01090>`_


**Source Science**

`A Glimpse of the Stellar Populations and Elemental Abundances of Gravitationally Lensed, Quiescent Galaxies at z≳1 with Keck Deep Spectroscopy <https://arxiv.org/abs/2212.04731>`_

`Discovery of a radio lobe in the Cloverleaf Quasar at z = 2.56 <https://arxiv.org/abs/2212.07027>`_

`ALMA [{N} {II}] 205 μm Imaging Spectroscopy of the Lensed Submillimeter Galaxy ID 141 at Redshift 4.24 <https://arxiv.org/abs/2006.01147>`_

`CO, H2O, H2O+ line & dust emission in a z = 3.63 strongly lensed starburst merger at sub-kiloparsec scales <https://arxiv.org/abs/1903.00273>`_

`The molecular-gas properties in the gravitationally lensed merger HATLAS J142935.3-002836 <https://arxiv.org/abs/1904.00307>`_

`Modelling high-resolution ALMA observations of strongly lensed dusty star forming galaxies detected by Herschel <https://arxiv.org/abs/2111.09680>`_

`ALMA resolves the first strongly-lensed Optical/NIR-dark galaxy <https://arxiv.org/abs/2207.00466>`_

`The Two 𝑧 ∼ 13 Galaxy Candidates HD1 and HD2 Are Likely Not Lensed <https://arxiv.org/abs/2209.06830>`_

`The Way of Water: ALMA resolves H2O emission lines in a strongly lensed dusty star-forming galaxy at z ∼ 3.1 <https://arxiv.org/abs/2304.08563>`_

`Characterisation of Herschel-selected strong lens candidates through HST and sub-mm/mm observations <https://arxiv.org/abs/2311.01158>`_

**Surveys**

`When Spectral Modeling Meets Convolutional Networks: A Method for Discovering Reionization-era Lensed Quasars in Multi-band Imaging Data <https://arxiv.org/abs/2211.14543>`_

`Modeling Strong Lenses from Wide-Field Ground-Based Observations in KiDS and GAMA <https://arxiv.org/abs/2301.05320>`_

`MNELLS: The MUSE Nearby Early-Type Galaxy Lens Locator Survey <https://arxiv.org/abs/2002.07191>`_

`Subaru FOCAS IFU observations of two z=0.12 strong-lensing elliptical galaxies from SDSS MaNGA <https://arxiv.org/abs/1911.06338>`_

